@@ -8,10 +8,12 @@ import sys
 import six
 
 import pytest
+from _pytest.main import EXIT_INTERRUPTED
 from _pytest.mark import EMPTY_PARAMETERSET_OPTION
 from _pytest.mark import MarkGenerator as Mark
 from _pytest.nodes import Collector
 from _pytest.nodes import Node
+from _pytest.warning_types import PytestDeprecationWarning
 from _pytest.warnings import SHOW_PYTEST_WARNINGS_ARG
 
 try:
@@ -859,20 +861,34 @@ def test_parameterset_for_fail_at_collect(testdir):
 
     config = testdir.parseconfig()
     from _pytest.mark import pytest_configure, get_empty_parameterset_mark
-    from _pytest.compat import getfslineno
 
     pytest_configure(config)
 
-    test_func = all
-    func_name = test_func.__name__
-    _, func_lineno = getfslineno(test_func)
-    expected_errmsg = r"Empty parameter set in '%s' at line %d" % (
-        func_name,
-        func_lineno,
-    )
+    with pytest.raises(
+        Collector.CollectError,
+        match=r"Empty parameter set in 'pytest_configure' at line \d\d+",
+    ):
+        get_empty_parameterset_mark(config, ["a"], pytest_configure)
 
-    with pytest.raises(Collector.CollectError, match=expected_errmsg):
-        get_empty_parameterset_mark(config, ["a"], test_func)
+    p1 = testdir.makepyfile(
+        """
+        import pytest
+
+        @pytest.mark.parametrize("empty", [])
+        def test():
+            pass
+        """
+    )
+    result = testdir.runpytest(str(p1))
+    result.stdout.fnmatch_lines(
+        [
+            "collected 0 items / 1 errors",
+            "* ERROR collecting test_parameterset_for_fail_at_collect.py *",
+            "Empty parameter set in 'test' at line 3",
+            "*= 1 error in *",
+        ]
+    )
+    assert result.ret == EXIT_INTERRUPTED
 
 
 def test_parameterset_for_parametrize_bad_markname(testdir):
@@ -976,3 +992,15 @@ def test_pytest_param_id_requires_string():
 @pytest.mark.parametrize("s", (None, "hello world"))
 def test_pytest_param_id_allows_none_or_string(s):
     assert pytest.param(id=s)
+
+
+def test_pytest_param_warning_on_unknown_kwargs():
+    with pytest.warns(PytestDeprecationWarning) as warninfo:
+        # typo, should be marks=
+        pytest.param(1, 2, mark=pytest.mark.xfail())
+    assert warninfo[0].filename == __file__
+    msg, = warninfo[0].message.args
+    assert msg == (
+        "pytest.param() got unexpected keyword arguments: ['mark'].\n"
+        "This will be an error in future versions."
+    )
